======
Support
======

We can only offer support for aws-msk-iam-sasl-signer-python library itself.

If you're having a problem with a library that uses aws-msk-iam-sasl-signer-python
(for example, dpkp or kafka-python), please open an issue
in that project's repository instead.

Q&A (please complete the following information)
-------
 - OS: [e.g. macOS]
 - Version: [e.g. 22.1.0]
 - Method of installation: [e.g. github]
 - aws-msk-iam-sasl-signer-python version: [e.g. 1.0.2]
 - Kafka library name: [e.g. kafka-python]
 - Kafka library version
 - Provide us a sample code snippet of your producer/consumer


Screenshots
----------
<!-- If applicable, add screenshots to help give context to your problem. -->

How can we help?
----------
<!-- Your question or problem goes here! -->
